@@ -158,13 +158,16 @@ sub EditFieldRender {
             $DataValues = { $Value => $Value };
         }
     }
+    elsif ( !IsHashRefWithData($DataValues) ) {
+        $DataValues = { ' ' => ' ' };
+    }
 
     my $HTMLString = $Param{LayoutObject}->BuildSelection(
         Data         => $DataValues || {},
         Name         => $FieldName,
         SelectedID   => $SelectedValuesArrayRef,
         Translation  => $FieldConfig->{TranslatableValues} || 0,
-        PossibleNone => 1,
+        PossibleNone => 0,
         TreeView     => $FieldConfig->{TreeView} || 0,
         Class        => $FieldClass,
         HTMLQuote    => 1,
@@ -232,7 +235,7 @@ EOF
     my $DynamicFieldSearch    = $FieldName . '_Search';
 
     $HTMLString
-        =~ s{(<select )}{$1 data-dynamic-field-name="$DynamicFieldName" data-dynamic-field-type="$DynamicFieldFieldType" data-selected-value-field-name="$FieldName" data-autocomplete-field-name="$DynamicFieldSearch" data-autocomplete-min-length="$AutocompleteMinLength" data-query-delay="$QueryDelay" data-default-search-term="$DefaultSearchTerm" data-ticket-id="$TicketID" };
+        =~ s{(<select )}{$1data-dynamic-field-name="$DynamicFieldName" data-dynamic-field-type="$DynamicFieldFieldType" data-selected-value-field-name="$FieldName" data-autocomplete-field-name="$DynamicFieldSearch" data-autocomplete-min-length="$AutocompleteMinLength" data-query-delay="$QueryDelay" data-default-search-term="$DefaultSearchTerm" data-ticket-id="$TicketID" };
 
     # Add InitSelect for search.
     my $DynamicFieldJS = <<"EOF";
@@ -555,7 +558,7 @@ sub SearchFieldRender {
         Name         => $FieldName,
         SelectedID   => $Value,
         Translation  => $FieldConfig->{TranslatableValues} || 0,
-        PossibleNone => 1,
+        PossibleNone => 0,
         TreeView     => $FieldConfig->{TreeView} || 0,
         Class        => $FieldClass,
         Multiple     => 1,
@@ -617,12 +620,18 @@ sub _AutocompleteSearchFieldRender {
         );
     }
 
+    if ( !IsHashRefWithData($SelectionData) ) {
+        $SelectionData = {
+            ' ' => ' ',
+        };
+    }
+
     my $HTMLString = $Param{LayoutObject}->BuildSelection(
         Data         => $SelectionData,
         Name         => $FieldName,
         SelectedID   => $FieldValues,
         Translation  => $FieldConfig->{TranslatableValues} || 0,
-        PossibleNone => 1,
+        PossibleNone => 0,
         TreeView     => 0,
         Class        => $FieldClass,
         Multiple     => 1,
@@ -868,11 +877,16 @@ sub PossibleValuesGet {
     my $DynamicFieldWebserviceObject = $Kernel::OM->Get('Kernel::System::DynamicField::Webservice');
     my $LayoutObject                 = $Kernel::OM->Get('Kernel::Output::HTML::Layout');
 
+    # to store the possible values
     my %PossibleValues;
 
-    # Provide empty value so the field will not be displayed as disabled if there are no selectable
-    # values yet.
-    $PossibleValues{' '} = '';
+    # set PossibleNone attribute
+    my $FieldPossibleNone = 1;
+
+    # set none value if defined on field config
+    if ( $FieldPossibleNone || !$Param{Value} ) {
+        %PossibleValues = ( ' ' => '-' );
+    }
 
     if ( $Param{DynamicFieldConfig}->{Config}->{InitialSearchTerm} ) {
         my $InitialSearchTerm = $LayoutObject->Ascii2Html(
